@@ -1,5 +1,5 @@
-/* Lziprecover - Data recovery tool for the lzip format
-   Copyright (C) 2009-2025 Antonio Diaz Diaz.
+/* Lziprecover - Data recovery tool
+   Copyright (C) 2009-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -377,8 +377,7 @@ public:
     crc_( 0xFFFFFFFFU ),
     outfd( ofd ),
     pos_wrapped( false )
-    // prev_byte of first byte; also for peek( 0 ) on corrupt file
-    { buffer[dictionary_size-1] = 0; }
+    { buffer[dictionary_size-1] = 0; }		// prev_byte of first byte
 
   ~LZ_decoder() { delete[] buffer; }
 
