@@ -1,5 +1,5 @@
-/* Lziprecover - Data recovery tool for the lzip format
-   Copyright (C) 2009-2025 Antonio Diaz Diaz.
+/* Lziprecover - Data recovery tool
+   Copyright (C) 2009-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -39,8 +39,11 @@ class Lzip_index
   long long insize;
   int retval_;
   unsigned dictionary_size_;	// largest dictionary size in the file
+  bool boxed_tdata_;		// all tdata is inside a single box
+  bool good_magic_;		// good magic in first header
 
-  bool check_header( const Lzip_header & header, const bool ignore_bad_ds );
+  bool check_header( const Lzip_header & header, const bool first,
+                     const bool ignore_bad_ds );
   void set_errno_error( const char * const msg );
   void set_num_error( const char * const msg, unsigned long long num );
   bool read_header( const int fd, Lzip_header & header, const long long pos );
@@ -63,6 +66,8 @@ public:
   const std::string & error() const { return error_; }
   int retval() const { return retval_; }
   unsigned dictionary_size() const { return dictionary_size_; }
+  bool boxed_tdata() const { return boxed_tdata_; }
+  bool good_magic() const { return good_magic_; }
 
   bool multi_empty() const	// multimember file with empty member(s)
     {
@@ -102,5 +107,26 @@ public:
     { return member_vector[i].dictionary_size; }
   };
 
+//const uint8_t box_magic[8] = { 0x54, 0x44, 0x41, 0x54, 0x41, 0x42, 0x4F, 0x58 };
+const uint8_t box_magic[8] = { 'T', 'D', 'A', 'T', 'A', 'B', 'O', 'X' };
+enum { min_box_size = 16 };
+
+struct Box_trailer
+  {
+  uint8_t data[8];		// box size including magic and trailer
+
+  unsigned long long box_size() const
+    {
+    unsigned long long tmp = 0;
+    for( int i = 7; i >= 0; --i ) { tmp <<= 8; tmp += data[i]; }
+    return tmp;
+    }
+
+  void box_size( unsigned long long sz )
+    { for( int i = 0; i <= 7; ++i ) { data[i] = (uint8_t)sz; sz >>= 8; } }
+  };
+
 int seek_read( const int fd, uint8_t * const buf, const int size,
                const long long pos );
+// return <0 if error
+long long skip_box( const int infd, long long pos, long long * box_sizep = 0 );
